@@ -8,9 +8,7 @@ import libpysal
 import numpy as np
 import pygeos
 import pandas as pd
-import shapely
 from scipy.spatial import Voronoi
-from shapely.geometry import Polygon
 from shapely.geometry.base import BaseGeometry
 from shapely.ops import polygonize
 from tqdm import tqdm
@@ -54,10 +52,7 @@ def buffered_limit(gdf, buffer=100):
     shapely.geometry.polygon.Polygon
 
     """
-    study_area = gdf.copy()
-    study_area["geometry"] = study_area.buffer(buffer)
-    built_up = study_area.geometry.unary_union
-    return built_up
+    return gdf.buffer(buffer).unary_union
 
 
 class Tessellation:
@@ -109,8 +104,8 @@ class Tessellation:
     enclosures : GeoDataFrame (default None)
         Enclosures geometry. Can  be generated using :func:`momepy.enclosures`.
     enclosure_id : str (default 'eID')
-        name of the enclosure_id containing unique identifer for each row in ``enclosures``.
-        Applies only if ``enclosures`` are passed.
+        name of the enclosure_id containing unique identifer for each row in
+        ``enclosures``. Applies only if ``enclosures`` are passed.
     threshold : float (default 0.05)
         The minimum threshold for a building to be considered within an enclosure.
         Threshold is a ratio of building area which needs to be within an enclosure to
@@ -211,36 +206,60 @@ class Tessellation:
                 "Pass `limit` for morphological tessellation or `enclosures` "
                 "for enclosed tessellation."
             )
+
+        gdf = gdf.copy()
+
         if enclosures is not None:
+
+            enclosures = enclosures.copy()
+
+            bounds = enclosures.total_bounds
+            centre_x = (bounds[0] + bounds[2]) / 2
+            centre_y = (bounds[1] + bounds[3]) / 2
+
+            gdf.geometry = gdf.geometry.translate(xoff=-centre_x, yoff=-centre_y)
+            enclosures.geometry = enclosures.geometry.translate(
+                xoff=-centre_x, yoff=-centre_y
+            )
+
             self.tessellation = self._enclosed_tessellation(
                 gdf, enclosures, unique_id, enclosure_id, threshold, use_dask, n_chunks,
             )
         else:
+            if isinstance(limit, (gpd.GeoSeries, gpd.GeoDataFrame)):
+                limit = limit.unary_union
+            if isinstance(limit, BaseGeometry):
+                limit = pygeos.from_shapely(limit)
+
+            bounds = pygeos.bounds(limit)
+            centre_x = (bounds[0] + bounds[2]) / 2
+            centre_y = (bounds[1] + bounds[3]) / 2
+            gdf.geometry = gdf.geometry.translate(xoff=-centre_x, yoff=-centre_y)
+
+            # add convex hull buffered large distance to eliminate infinity issues
+            limit = (
+                gpd.GeoSeries(limit, crs=gdf.crs)
+                .translate(xoff=-centre_x, yoff=-centre_y)
+                .values.data[0]
+            )
+
             self.tessellation = self._morphological_tessellation(
                 gdf, unique_id, limit, shrink, segment, verbose
             )
 
+        self.tessellation["geometry"] = self.tessellation["geometry"].translate(
+            xoff=centre_x, yoff=centre_y
+        )
+
     def _morphological_tessellation(
         self, gdf, unique_id, limit, shrink, segment, verbose, check=True
     ):
-        objects = gdf.copy()
-
-        if isinstance(limit, (gpd.GeoSeries, gpd.GeoDataFrame)):
-            limit = limit.unary_union
-        if isinstance(limit, BaseGeometry):
-            limit = pygeos.from_shapely(limit)
-
-        bounds = pygeos.bounds(limit)
-        centre_x = (bounds[0] + bounds[2]) / 2
-        centre_y = (bounds[1] + bounds[3]) / 2
-        objects["geometry"] = objects["geometry"].translate(
-            xoff=-centre_x, yoff=-centre_y
-        )
+        objects = gdf
 
         if shrink != 0:
             print("Inward offset...") if verbose else None
             mask = objects.type.isin(["Polygon", "MultiPolygon"])
-            objects.loc[mask, "geometry"] = objects[mask].buffer(
+            objects.loc[mask, objects.geometry.name] = objects[mask].buffer(
                 -shrink, cap_style=2, join_style=2
             )
 
@@ -252,18 +271,14 @@ class Tessellation:
             objects.geometry.values.data, distance=segment, index=objects.index
         )
 
-        # add convex hull buffered large distance to eliminate infinity issues
-        series = gpd.GeoSeries(limit, crs=gdf.crs).translate(
-            xoff=-centre_x, yoff=-centre_y
-        )
+        hull = pygeos.convex_hull(limit)
+        bounds = pygeos.bounds(hull)
         width = bounds[2] - bounds[0]
         leng = bounds[3] - bounds[1]
-        hull = series.geometry[[0]].buffer(2 * width if width > leng else 2 * leng)
-        # pygeos bug fix
-        if (hull.type == "MultiPolygon").any():
-            hull = hull.explode()
+        hull = pygeos.buffer(hull, 2 * width if width > leng else 2 * leng)
+
         hull_p, hull_ix = self._dense_point_array(
-            hull.values.data, distance=pygeos.length(limit) / 100, index=hull.index
+            [hull], distance=pygeos.length(hull) / 100, index=[0]
         )
         points = np.append(points, hull_p, axis=0)
         ids = ids + ([-1] * len(hull_ix))
@@ -279,11 +294,9 @@ class Tessellation:
             by=unique_id, as_index=False
         )
 
-        morphological_tessellation = gpd.clip(morphological_tessellation, series)
-
-        morphological_tessellation["geometry"] = morphological_tessellation[
-            "geometry"
-        ].translate(xoff=centre_x, yoff=centre_y)
+        morphological_tessellation = gpd.clip(
+            morphological_tessellation, gpd.GeoSeries(limit, crs=gdf.crs)
+        )
 
         if check:
             self._check_result(morphological_tessellation, gdf, unique_id=unique_id)
@@ -295,7 +308,7 @@ class Tessellation:
         geoms - array of pygeos lines
         """
         # interpolate lines to represent them as points for Voronoi
-        points = np.empty((0, 2))
+        points = []
         ids = []
 
         if pygeos.get_type_id(geoms[0]) not in [1, 2, 5]:
@@ -309,9 +322,11 @@ class Tessellation:
                     line,
                     np.linspace(0.1, length - 0.1, num=int((length - 0.1) // distance)),
                 )  # .1 offset to keep a gap between two segments
-                points = np.append(points, pygeos.get_coordinates(pts), axis=0)
+                points.append(pygeos.get_coordinates(pts))
                 ids += [ix] * len(pts)
 
+        points = np.vstack(points)
+
         return points, ids
 
         # here we might also want to append original coordinates of each line
@@ -340,7 +355,7 @@ class Tessellation:
 
     def _check_result(self, tesselation, orig_gdf, unique_id):
         """
-        Check whether result of tessellation matches buildings and contains only Polygons.
+        Check whether result matches buildings and contains only Polygons.
         """
         # check against input layer
         ids_original = list(orig_gdf[unique_id])
@@ -350,10 +365,9 @@ class Tessellation:
 
             self.collapsed = set(ids_original).difference(ids_generated)
             warnings.warn(
-                "Tessellation does not fully match buildings. {len} element(s) collapsed "
-                "during generation - unique_id: {i}".format(
-                    len=len(self.collapsed), i=self.collapsed
-                )
+                f"Tessellation does not fully match buildings. "
+                f"{len(self.collapsed)} element(s) collapsed "
+                f"during generation - unique_id: {self.collapsed}"
             )
 
         # check MultiPolygons - usually caused by error in input geometry
@@ -364,8 +378,8 @@ class Tessellation:
             import warnings
 
             warnings.warn(
-                "Tessellation contains MultiPolygon elements. Initial objects should be edited. "
-                "unique_id of affected elements: {}".format(list(self.multipolygons))
+                "Tessellation contains MultiPolygon elements. Initial objects should "
+                f"be edited. unique_id of affected elements: {list(self.multipolygons)}"
             )
 
     def _enclosed_tessellation(
@@ -380,28 +394,29 @@ class Tessellation:
         **kwargs,
     ):
         """Enclosed tessellation
-        Generate enclosed tessellation based on barriers defining enclosures and buildings
-        footprints.
+        Generate enclosed tessellation based on barriers defining enclosures and
+        building footprints.
 
         Parameters
         ----------
         buildings : GeoDataFrame
-            GeoDataFrame containing building footprints. Expects (Multi)Polygon geometry.
+            GeoDataFrame containing building footprints. Expects (Multi)Polygon
+            geometry.
         enclosures : GeoDataFrame
             Enclosures geometry. Can  be generated using :func:`momepy.enclosures`.
         unique_id : str
             name of the column with unique id of buildings gdf
         threshold : float (default 0.05)
             The minimum threshold for a building to be considered within an enclosure.
-            Threshold is a ratio of building area which needs to be within an enclosure to
-            inlude it in the tessellation of that enclosure. Resolves sliver geometry
+            Threshold is a ratio of building area which needs to be within an enclosure
+            to inlude it in the tessellation of that enclosure. Resolves sliver geometry
             issues.
         use_dask : bool (default True)
             Use parallelised algorithm based on ``dask.dataframe``. Requires dask.
         n_chunks : None
-            Number of chunks to be used in parallelization. Ideal is one chunk per thread.
-            Applies only if ``enclosures`` are passed. Defualt automatically uses
-            n == dask.system.cpu_count.
+            Number of chunks to be used in parallelization. Ideal is one chunk per
+            thread. Applies only if ``enclosures`` are passed. Defualt automatically
+            uses n == dask.system.cpu_count.
         **kwargs
             Keyword arguments passed to Tessellation algorithm (as ``shrink``
             or ``segment``).
@@ -443,9 +458,8 @@ class Tessellation:
                     "dask.dataframe could not be imported. Setting `use_dask=False`."
                 )
 
-        if use_dask:
             if n_chunks is None:
-                n_chunks = cpu_count()
+                n_chunks = cpu_count() - 1 if cpu_count() > 1 else 1
             # initialize dask.series
             ds = dd.from_array(splits, chunksize=len(splits) // n_chunks)
             # generate enclosed tessellation using dask
@@ -537,7 +551,8 @@ class Blocks:
     id_name : str
         name of the unique blocks id column to be generated
     unique_id : str
-        name of the column with unique id. If there is none, it could be generated by :func:`momepy.unique_id`.
+        name of the column with unique id. If there is none, it could be generated
+        by :func:`momepy.unique_id`.
         This should be the same for cells and buildings, id's should match.
 
     Attributes
@@ -561,7 +576,7 @@ class Blocks:
 
     Examples
     --------
-    >>> blocks_generate = mm.Blocks(tessellation_df, streets_df, buildings_df, 'bID', 'uID')
+    >>> blocks = mm.Blocks(tessellation_df, streets_df, buildings_df, 'bID', 'uID')
     Buffering streets...
     Generating spatial index...
     Difference...
@@ -575,7 +590,7 @@ class Blocks:
     Multipart to singlepart...
     Attribute join (buildings)...
     Attribute join (tesselation)...
-    >>> blocks_generate.blocks.head()
+    >>> blocks.blocks.head()
         bID	geometry
     0	1.0	POLYGON ((1603560.078648818 6464202.366899694,...
     1	2.0	POLYGON ((1603457.225976106 6464299.454696888,...
@@ -606,19 +621,22 @@ class Blocks:
         W = libpysal.weights.Queen.from_dataframe(cut, silence_warnings=True)
         cut["component"] = W.component_labels
         buildings_c = buildings.copy()
-        buildings_c["geometry"] = buildings_c.representative_point()  # make points
+        buildings_c.geometry = buildings_c.representative_point()  # make points
         centroids_tempID = gpd.sjoin(
-            buildings_c, cut[["geometry", "component"]], how="left", op="intersects"
+            buildings_c,
+            cut[[cut.geometry.name, "component"]],
+            how="left",
+            op="intersects",
         )
-        cells_copy = tessellation[[unique_id, "geometry"]].merge(
+        cells_copy = tessellation[[unique_id, tessellation.geometry.name]].merge(
             centroids_tempID[[unique_id, "component"]], on=unique_id, how="left"
         )
         blocks = cells_copy.dissolve(by="component").explode().reset_index(drop=True)
         blocks[id_name] = range(len(blocks))
-        blocks["geometry"] = gpd.GeoSeries(
+        blocks[blocks.geometry.name] = gpd.GeoSeries(
             pygeos.polygons(blocks.exterior.values.data), crs=blocks.crs
         )
-        blocks = blocks[[id_name, "geometry"]]
+        blocks = blocks[[id_name, blocks.geometry.name]]
 
         centroids_w_bl_ID2 = gpd.sjoin(buildings_c, blocks, how="left", op="intersects")
         bl_ID_to_uID = centroids_w_bl_ID2[[unique_id, id_name]]
@@ -691,7 +709,7 @@ def get_network_id(left, right, network_id, min_size=100, verbose=True):
     print("Generating centroids...") if verbose else None
     buildings_c = left.copy()
 
-    buildings_c["geometry"] = buildings_c.centroid  # make centroids
+    buildings_c[buildings_c.geometry.name] = buildings_c.centroid  # make centroids
 
     print("Generating rtree...") if verbose else None
     idx = right.sindex
@@ -920,39 +938,6 @@ def get_network_ratio(df, edges, initial_buffer=500):
     return result
 
 
-def _split_lines(polygon, distance):
-    """Split polygon into GeoSeries of lines no longer than `distance`."""
-    list_points = []
-    current_dist = distance  # set the current distance to place the point
-
-    # TODO: use pygeos interpolate
-    boundary = polygon.boundary  # make shapely MultiLineString object
-    if boundary.type == "LineString":
-        line_length = boundary.length  # get the total length of the line
-        while (
-            current_dist < line_length
-        ):  # while the current cumulative distance is less than the total length of the line
-            list_points.append(
-                boundary.interpolate(current_dist)
-            )  # use interpolate and increase the current distance
-            current_dist += distance
-    elif boundary.type == "MultiLineString":
-        for ls in boundary:
-            line_length = ls.length  # get the total length of the line
-            while (
-                current_dist < line_length
-            ):  # while the current cumulative distance is less than the total length of the line
-                list_points.append(
-                    ls.interpolate(current_dist)
-                )  # use interpolate and increase the current distance
-                current_dist += distance
-
-    cutted = shapely.ops.split(
-        boundary, shapely.geometry.MultiPoint(list_points).buffer(0.001)
-    )
-    return cutted
-
-
 def enclosures(
     primary_barriers, limit=None, additional_barriers=None, enclosure_id="eID"
 ):
