@@ -110,7 +110,7 @@ def preprocess(
                         shares = {}
                         for n in row.neighbors:
                             shares[n] = row.geometry.intersection(
-                                blg.at[n, "geometry"]
+                                blg.at[n, blg.geometry.name]
                             ).length
                         maximal = max(shares.items(), key=operator.itemgetter(1))[0]
                         uid = blg.loc[maximal].mm_uid
@@ -136,7 +136,7 @@ def preprocess(
                         shares = {}
                         for n in row.neighbors:
                             shares[n] = row.geometry.intersection(
-                                blg.at[n, "geometry"]
+                                blg.at[n, blg.geometry.name]
                             ).length
                         maximal = max(shares.items(), key=operator.itemgetter(1))[0]
                         uid = blg.loc[maximal].mm_uid
@@ -150,7 +150,7 @@ def preprocess(
             if islands:
                 if row.n_count == 1:
                     shared = row.geometry.intersection(
-                        blg.at[row.neighbors[0], "geometry"]
+                        blg.at[row.neighbors[0], blg.geometry.name]
                     ).length
                     if shared == row.geometry.exterior.length:
                         uid = blg.iloc[row.neighbors[0]].mm_uid
@@ -174,7 +174,9 @@ def preprocess(
                         geoms.append(blg[blg["mm_uid"] == j].iloc[0].geometry)
                         blg.drop(blg[blg["mm_uid"] == j].index[0], inplace=True)
                 new_geom = shapely.ops.unary_union(geoms)
-                blg.loc[blg.loc[blg["mm_uid"] == key].index[0], "geometry"] = new_geom
+                blg.loc[
+                    blg.loc[blg["mm_uid"] == key].index[0], blg.geometry.name
+                ] = new_geom
 
         blg.drop(delete, inplace=True)
     return blg[buildings.columns]
@@ -207,6 +209,7 @@ def remove_false_nodes(gdf):
         geom = df.geometry.values.data
     else:
         geom = gdf
+        df = gpd.GeoSeries(gdf)
 
     # extract array of coordinates and number per geometry
     coords = pygeos.get_coordinates(geom)
@@ -480,7 +483,7 @@ def network_false_nodes(gdf, tolerance=0.1, precision=3, verbose=True):
     streets = gdf.reset_index(drop=True).explode().reset_index(drop=True)
     if isinstance(streets, gpd.GeoDataFrame):
         series = False
-    elif isinstance(streets, gpd.GeoSeries):
+    else:
         series = True
 
     sindex = streets.sindex
@@ -530,14 +533,14 @@ def network_false_nodes(gdf, tolerance=0.1, precision=3, verbose=True):
                 if series:
                     geoms.loc[idx] = linestring
                 else:
-                    geoms.loc[idx, "geometry"] = linestring
+                    geoms.loc[idx, geoms.geometry.name] = linestring
                 idx += 1
             elif linestring.type == "MultiLineString":
                 for g in linestring.geoms:
                     if series:
                         geoms.loc[idx] = g
                     else:
-                        geoms.loc[idx, "geometry"] = g
+                        geoms.loc[idx, geoms.geometry.name] = g
                     idx += 1
 
             geoms = geoms.drop(matches.index)
